function mr_accumulate ()
% reads real-time (or simulated real-time) data and accumulates it in the mr.accumulatedData field. To save memory and prevent slowdown due to disk-swapping, the length of data accumulated in mr.accumulatedData can be limited automatically in this function by setting the mr.maxNumberOfFramesInAccumulatedData field to a finite value. 
global mr
global ds_array
maximumDataToReadInEachRun = 2000; % maximum number of frames to be read in each acumulation run
counter = 1;
sizeOfBlockInceaseInAccumulatedDataSize = 30000;

r=1;
arr_in = ds_array; 

persistent n;

if isempty(n)
    n = 0;
end;

while  counter<maximumDataToReadInEachRun
    
    if mr.readFromDataRiver
%        if n<100
%             [r,arr_in] = ds_Read(mr.readBufferHandle1);
%             readbdfR = r
%             
%             n = n + 1;
%         else
            [r,arr_in] = ds_Read(mr.readBufferHandle);
          %  DatariverR = r
%         end;
    else
        [r,arr_in] = mr_read_simulated;
    end;
    
    if r>0
        %newData = cat(2,newData, arr_in.Data(1:arr_in.nItems)');
        
        % add new data to the accumulator variable 'mr.accumulatedData'
        mr.numberOfChannelsInAccumulatedData = arr_in.nItems;
        
        if mr.numberOfFramesInAccumulatedData+1 > size(mr.accumulatedData)
            % expand the data if it has not resched the maximum allowed
            % size
            if mr.numberOfFramesInAccumulatedData<mr.maxNumberOfFramesInAccumulatedData                
               if mr.verboseLevel > 0
                    fprintf('mr.accumulatedData expansion started...\n');
                end;
                mr.accumulatedData = cat(2, mr.accumulatedData, nan(size(mr.accumulatedData,1), sizeOfBlockInceaseInAccumulatedDataSize));
                if mr.verboseLevel > 0
                    fprintf('mr.accumulatedData expanded.\n');
                end;
            else % shrink accumulated data size if it has reached the max allowed size
                mr.accumulatedData = cat(2, mr.accumulatedData(:, (mr.numberOfFramesInAccumulatedData - mr.maxNumberOfFramesInAccumulatedData):mr.numberOfFramesInAccumulatedData), nan(size(mr.accumulatedData,1), sizeOfBlockInceaseInAccumulatedDataSize));
                mr.numberOfFramesInAccumulatedData = mr.maxNumberOfFramesInAccumulatedData;
                if mr.verboseLevel > 0
                    fprintf('mr.accumulatedData shrunk.\n');
                end;
            end;
        end;
        
        mr.accumulatedData(1:mr.numberOfChannelsInAccumulatedData, mr.numberOfFramesInAccumulatedData+1) = arr_in.Data(1:arr_in.nItems);
        mr.numberOfFramesInAccumulatedData = mr.numberOfFramesInAccumulatedData + 1;
        mr.numberOfFramesReceived =  mr.numberOfFramesReceived + 1;
    else
        break;
    end;
    counter = counter + 1;
end


% run the function given by handle after data is updated
if isa(mr.functionHandle, 'function_handle')
    mr.functionHandle();
end;
