function channelOffset = mr_calculate_channel_offset(channelNumbers, doReset)
%
% calculate 0-Hz offset for EEG channels (specified by channelNumbers
% indexed from the original accumulatedData ids)
%
% Usage:
%
%   channelOffset = mr_calculate_channel_offset(channelNumbers)

global mr;

meanWindowSize = 6000;

persistent lastChannelNumbers lastNumberOfFramesInAccumulatedData lastChannelOffset

if nargin>1 && doReset
    lastChannelNumbers = [];
    lastNumberOfFramesInAccumulatedData = 0;
    return;
end;
    

% update offset calculations if either the challe numbers have changed, the last calculated offsets are
% too old or less than half of meanWindowSize has passed.
if ~isempty(setxor(channelNumbers, lastChannelNumbers)) || mr.numberOfFramesInAccumulatedData  >  lastNumberOfFramesInAccumulatedData + 100 || mr.numberOfFramesInAccumulatedData < meanWindowSize
    % upadte (re-calculate) channelOffset numbers
    
    startFrame  = max(1, mr.numberOfFramesInAccumulatedData - meanWindowSize);
    
    channelOffset = mean(mr.accumulatedData(channelNumbers, startFrame:mr.numberOfFramesInAccumulatedData),2);
    
    lastChannelNumbers = channelNumbers;
    lastNumberOfFramesInAccumulatedData =  mr.numberOfFramesInAccumulatedData;
    lastChannelOffset = channelOffset;
    
else % preset last calculated channel offset numbers (since they do not change very fast)
    channelOffset = lastChannelOffset;
end;

% below is the code for a moving average with a certain length, seems to
% not be necessary and too complicated at this moment since calculating
% average for last 5000 point should be fast enough
% 
% persistent lastStartFrame lastEndFrame meanWindowSize lastSum numberOfFramesInSum;
% 
% if nargin<1
%     doReset = false;
% end;
% 
% 
% if doReset || isempty(lastStartFrame)
%     lastStartFrame  =1;
%     lastEndFrame  =1;
%     meanWindowSize = 4000;
%     lastSum = 0;
%     numberOfFramesInSum = 0;
% 
%     if doReset
%         channelOffset = [];
%         return
%     end;
% 
% end;
% 
% for frame=(lastEndFrame+1):mr.numberOfFramesInAccumulatedData
%     if frame <= meanWindowSize
%         lastSum = lastSum + EEG.data(:, frame);
%         numberOfFramesInSum = numberOfFramesInSum + 1;
%     else
%         lastSum = lastSum + + EEG.data(:, frame) - EEG.data(:, lastStartFrame);
%         lastStartFrame = lastStartFrame + 1;
%     end;
% 
%     channelOffset = lastSum / numberOfFramesInSum;
% end;
% 
% 
% lastEndFrame = mr.numberOfFramesInAccumulatedData;