function mr_circular_read_buffer_add(bufferId, newValues)
% mr_circular_read_buffer_add(bufferId, newValues) is similar to
% circular_buffer_add but uses global mr variable to significantly (5x)
% speed-up access to buffer values.
%
% newValues must be channels  x number of frames
% bufferId = find(strcmp(mr.read.bufferName, bufferName)); but should be
% provided outside the function to increase speed.

global mr;

% expand buffer dimensions if new values have larger number of channels,
% values for previous data are filled will zeros for new channels
if size(newValues, 1) > size(mr.read.bufferAccumulatedData(bufferId).buffer, 1)
    mr.read.bufferAccumulatedData(bufferId).buffer(size(mr.read.bufferAccumulatedData(bufferId).buffer, 1)+1:size(newValues, 1), :) = 0;
    fprintf('Buffer channels expanded to %d in order to accomodate newly added values.\n', size(mr.read.bufferAccumulatedData(bufferId).buffer, 1));
end;

newValueLength = size(newValues, 2);

% prevent multiple wrap-around if new values have a large length than
% buffer
if newValueLength > mr.read.bufferAccumulatedData(bufferId).length-1 % the actual capacity of buffer is mr.read.bufferAccumulatedData(bufferId).length because of one unused location between start and end
    % cut new value size to fit in the buffer
    newValues = newValues(:, (end-mr.read.bufferAccumulatedData(bufferId).length + 2):end);
    newValueLength = size(newValues, 2);
end;

if newValueLength <= (mr.read.bufferAccumulatedData(bufferId).length  - mr.read.bufferAccumulatedData(bufferId).endId)
    
    % single straight block in buffer
    if newValueLength == 1
        mr.read.bufferAccumulatedData(bufferId).buffer(:, mr.read.bufferAccumulatedData(bufferId).endId + 1) = newValues;
    else
        mr.read.bufferAccumulatedData(bufferId).buffer(:, (mr.read.bufferAccumulatedData(bufferId).endId + 1):(mr.read.bufferAccumulatedData(bufferId).endId + newValueLength)) = newValues;
    end;
    
    mr.read.bufferAccumulatedData(bufferId).endId = mr.read.bufferAccumulatedData(bufferId).endId + newValueLength;
    
    if mr.read.bufferAccumulatedData(bufferId).isFull
        mr.read.bufferAccumulatedData(bufferId).startId = mr.read.bufferAccumulatedData(bufferId).endId + 2; % there should always be an empty location between start and end
        if mr.read.bufferAccumulatedData(bufferId).startId > mr.read.bufferAccumulatedData(bufferId).length
            mr.read.bufferAccumulatedData(bufferId).startId = mr.read.bufferAccumulatedData(bufferId).startId - mr.read.bufferAccumulatedData(bufferId).length;
        end;
    end;
    
else % wrap around
    bufferSegmentUntilEnd = (mr.read.bufferAccumulatedData(bufferId).endId + 1):mr.read.bufferAccumulatedData(bufferId).length;
    bufferSegmentFromBeginning = 1:(newValueLength - length(bufferSegmentUntilEnd));
    
    mr.read.bufferAccumulatedData(bufferId).buffer(:, bufferSegmentUntilEnd) = newValues(:, 1:length(bufferSegmentUntilEnd));
    mr.read.bufferAccumulatedData(bufferId).buffer(:, bufferSegmentFromBeginning) = newValues(:, length(bufferSegmentUntilEnd)+1:end);
    
    mr.read.bufferAccumulatedData(bufferId).endId = length(bufferSegmentFromBeginning);
    
    if mr.read.bufferAccumulatedData(bufferId).endId >= mr.read.bufferAccumulatedData(bufferId).startId
        mr.read.bufferAccumulatedData(bufferId).startId = mr.read.bufferAccumulatedData(bufferId).endId + 2; % there should always be an empty location between start and end
        if mr.read.bufferAccumulatedData(bufferId).startId > mr.read.bufferAccumulatedData(bufferId).length
            mr.read.bufferAccumulatedData(bufferId).startId = mr.read.bufferAccumulatedData(bufferId).startId - mr.read.bufferAccumulatedData(bufferId).length;
        end;
        mr.read.bufferAccumulatedData(bufferId).isFull = true;
    end;
    
end;