function mr_init_reading(bufferName, numberOfChannels, circularBufferLength)

global mr;
global ds_lib;

if ~isfield(mr,'readFromDataRiver') || (mr.readFromDataRiver && (~exist('ds_lib') || isempty(ds_lib)))
    startup_ds;
end;

if nargin<2
    numberOfChannels = 1;
    if mr.verboseLevel > 0
        fprintf('DataRiver Warning: numberOfChannels was not provided. A one (1) channel buffer assumed.\n', bufferName);
    end;
end;

if nargin<3
    circularBufferLength = 5000; % default buffer lenght
end;

% create the field if not exist
if ~isfield(mr, 'read') || ~isfield(mr.read, 'bufferName')
    mr.read.bufferName = {};
    mr.read.bufferHandle = [];
    mr.read.numberOfFramesReceived = [];
end;

% initiate buffer and create the handle to it if it does not already exist
if ~any(strcmp(mr.read.bufferName, bufferName))
    mr.read.bufferName{end + 1} = bufferName;
    
    if mr.readFromDataRiver % to prevent connecting to DataRiver in simulated real-time mode.
        mr.read.bufferHandle{end + 1} = ds_Openread(bufferName);
    end;
    
    mr.read.numberOfFramesReceived(end + 1) = 0;
    
    if isfield(mr.read, 'bufferAccumulatedData') && ~isempty(mr.read.bufferAccumulatedData)
        mr.read.bufferAccumulatedData(end+1) = circular_buffer_init(circularBufferLength , numberOfChannels);
    else
        mr.read.bufferAccumulatedData = circular_buffer_init(circularBufferLength , numberOfChannels);
    end;
    
    if mr.verboseLevel > 0
        fprintf('DataRiver read buffer ''%s'' initiated.\n', bufferName);
    end;
else
    fprintf('DataRiver buffer was already initiated. Nothing to do.\n');
end;
