function mr_power_on_cortex(doReset)

global mr

persistent figureHandle fsfVertextDistanceToDipole numberOfColorsInTheColormap colorMapIsHasNegative fsfHandle maxFrameDistance;
persistent numberOfRunsSofar lastMax lastMin dipoleProjectionOnAllCortext wavelet maxWaveletLength;

if nargin<1
    doReset = false;
end;


if doReset || isempty(figureHandle) || ~ishandle(figureHandle)
    
    fsf = load('/home/nima/tools/eeg/MNImesh_dipfit.mat');
    
    figureHandle = figure;
    fsfHandle = plotmesh(fsf.faces, fsf.vertices, [], false);
    
    set(gcf,'Renderer' ,'opengl');
    reducepatch(fsfHandle, 1/6);
    
    % simple gaussian projection on surface
    
    gaussianStd = 2;%4;
    
    fsfVertices = get(fsfHandle(1), 'Vertices');
    clear diplePosition
    
    % assume dipoles are located at the channel location, this is more
    % meanngful when we use sphering, which produces 'dipoles' at channel
    % locations
    for i=1:length(mr.eeg.channelNumbers)
        % transfer channel location into MNI space (coordinate system) 
        dipolePosition{i} = (traditionaldipfit(mr.eeg.dipfit.coord_transform) * [mr.eeg.chanlocs(i).X mr.eeg.chanlocs(i).Y mr.eeg.chanlocs(i).Z 1]')';
        dipolePosition{i} = dipolePosition{i}(1:3);
    end;


    clear projection ;
    fsfVertextDistanceToDipole = [];
    for i=1:length(dipolePosition)
        fsfVertextDistanceToDipole(i,:) = sum( (fsfVertices - repmat(dipolePosition{i}, size(fsfVertices, 1), 1)) .^2, 2) .^ 0.5;
        projection(i,:) = exp((-1/(2*gaussianStd^2)) *fsfVertextDistanceToDipole(i,:));
    end;
    
    
    dipoleProjectionOnAllCortext = projection;
    %
    % set the appropriate colormap
    load('/home/nima/tools/cortex_viz/cortex_gray_colormap_with_only_warm_colors');
    load('/home/nima/tools/cortex_viz/cortex_gray_colormap_with_in_jet_middle.mat');
    
    colorMapIsHasNegative = true;
    
    if colorMapIsHasNegative
        set(figureHandle, 'colormap',cortexGrayInMiddleOfJet);        
    else
        set(figureHandle, 'colormap', cortexGrayWithOnlyWarmColors);
    end;
    
    numberOfColorsInTheColormap = length(get(gcf,'Colormap'));
    
    
    set(fsfHandle, 'CDataMapping','direct');
    set(fsfHandle, 'FaceColor','interp');
    
    % for the mean max and min used in the colormap 
    numberOfRunsSofar = 0;
    lastMin = 0;
    lastMax = 0;
    
    
    % frequency band and wavelets
     frequencyBand = [3 7]; % theta
  %  frequencyBand = [8 12]; % alpha
    %frequencyBand = [30 80]; % gammma
    [wavelet,cycles,freqresol,timeresol] = dftfilt3( frequencyBand(1):0.5:frequencyBand(2), 3, mr.samplingRate);
    maxWaveletLength = -inf;
    for i=1:length(wavelet)
        maxWaveletLength = max([maxWaveletLength length(wavelet{i})]);
    end;
end;

if mr.numberOfFramesInAccumulatedData > mr.samplingRate*2

    mr_raw_to_ic_activity_accumulate; % make sure all ica is calculated
    
    
    
   % sumOfpower = powerAtBand(mr.eeg.accumulatedIcActivity(:,(end-maxWaveletLength+1):end), wavelet);
    sumOfpower = powerAtBand(circular_buffer_last_frames(mr.eeg.accumulatedIcActivity, maxWaveletLength), wavelet);
    
   % sumOfpower = mr.eeg.accumulatedIcActivity(:,end);
    
    totalDipoleProjection = 0;
    for i=1:size(fsfVertextDistanceToDipole, 1)
        %activityToPlot = mr.eeg.accumulatedIcActivity(i,:);
        totalDipoleProjection =  totalDipoleProjection +sumOfpower(i) .* dipoleProjectionOnAllCortext(i,:);        
    end;
    
    %lastMin = (lastMin * numberOfRunsSofar + min(totalDipoleProjection(:))) / (numberOfRunsSofar+1);
    lastMax = (lastMax * numberOfRunsSofar + max(totalDipoleProjection(:))) / (numberOfRunsSofar+1);
    numberOfRunsSofar = numberOfRunsSofar + 1;
    
    
    if colorMapIsHasNegative
        maxAbsProjection = max(abs(totalDipoleProjection));
        adjustedTotalDipoleProjectionOverAllFrames = 0.5 * totalDipoleProjection / maxAbsProjection; % map the max value to 0.5
        colorValue =  (adjustedTotalDipoleProjectionOverAllFrames+ 0.5) * (numberOfColorsInTheColormap);
    else
        adjustedTotalDipoleProjectionOverAllFrames = totalDipoleProjection / lastMax;
        adjustedTotalDipoleProjectionOverAllFrames(adjustedTotalDipoleProjectionOverAllFrames>1) = 1;
        colorValue =  adjustedTotalDipoleProjectionOverAllFrames * (numberOfColorsInTheColormap);
    end;
    
    
    set(fsfHandle, 'Cdata', colorValue);
    drawnow;
end;
end

function sumOfpower = powerAtBand(data, wavelet)
for dataChannelNumber = 1:size(data,1)
    sumOfpower(dataChannelNumber) = 0;
    for waveletNumber = 1:length(wavelet)        
        sumOfpower(dataChannelNumber) = sumOfpower(dataChannelNumber) +abs( data(dataChannelNumber, (end-length(wavelet{waveletNumber})+1):end) * wavelet{waveletNumber}') ^ 2;
    end;
end;
end

