function icActivitySuccessfullyCalculated = mr_raw_to_ic_activity(accumulatedDataframes)
% calculate activity of select ICs in a limited duration and place it 
% in mr.eeg.icActivity field. 
% accumulatedDataframes are the frames in accumulated Data from which ica
% activities should be calculated

global mr

icActivityDurationToCalculateInFrames = mr.eeg.icActivityDurationToCalculate * mr.samplingRate/1000;

if nargin<1
    accumulatedDataframes = max(1, mr.numberOfFramesInAccumulatedData - icActivityDurationToCalculateInFrames+1):mr.numberOfFramesInAccumulatedData;
else
    if isempty(accumulatedDataframes) || min(accumulatedDataframes)<1 || max(accumulatedDataframes)>mr.numberOfFramesInAccumulatedData
        icActivitySuccessfullyCalculated = false;
        return;
    end;
end;

% extract eeg channel data (or subset of EEG channels) from all channels
% (which may contain mocap, event or other data too)

if mr.numberOfFramesInAccumulatedData == 0 
    mr.eeg.icActivity = [];
    icActivitySuccessfullyCalculated = false;
    return;
else % reference channel is either a number, or the string 'average'
    if mr.eeg.reference_is_included 
        % means that the reference channel index is relative to channel subset indices
        eegData = channel_subset_and_re_reference_to_included_reference(mr, accumulatedDataframes);
    else 
        % means that the reference channel index is relative to original
        % (all) accumulated channel data
        eegData = channel_subset_and_re_reference_to_non_included_reference(mr, accumulatedDataframes);
    end;
end;



% calculate activity of request ICs (generally only a subset of IC activities are calclated to save execution time)
mr.eeg.icActivity = mr.eeg.activeIcaUnmix(mr.eeg.icNumbersToCalculateActivity, :) * eegData;

% highpass and lowpass filtering of ic activty
mr.eeg.icActivity = eegfiltfft(mr.eeg.icActivity, mr.samplingRate, mr.eeg.locutoff, mr.eeg.hicutoff);

icActivitySuccessfullyCalculated = true;

end




% a copy of eegfiltfft() with text output disabled.
function smoothdata = eegfiltfft(data, fs, lowcut, highcut, epochframes, filtorder, revfilt)
    
    if nargin < 4
        help eegfiltfft;
    end;
    [chans frames] = size(data);
    if nargin < 5 | epochframes == 0
        epochframes = frames;
    end
    if nargin < 7
        revfilt = 0;
    end;
    
    epochs = frames/epochframes;
    if epochs ~= round(epochs)
        error('Epochframes does not divide the total number of frames');
    end;
    fv=reshape([0:epochframes-1]*fs/epochframes,epochframes,1); % Frequency vector for plotting    
    
    %figure;
    %plot(fv, 20*log(abs(X))/log(10))  % Plot power spectrum in dB scale
    %xlabel('Frequency [Hz]')
    %ylabel('Signal power [dB]')
    
    % find closest freq in fft decomposition
    % --------------------------------------
    if lowcut ~= 0
        [tmp idxl]=min(abs(fv-lowcut));  % Find the entry in fv closest to 5 kHz
    else
        idxl = 0;
    end;
    if highcut ~= 0        
        [tmp idxh]=min(abs(fv-highcut));  % Find the entry in fv closest to 5 kHz    
    else 
        idxh = ceil(length(fv)/2);
    end;
    
    % filter the data
    % ---------------
    smoothdata = zeros(chans,frames);
    for e = 1:epochs                % filter each epoch, channel 
        for c=1:chans
            X=fft(data(c,(e-1)*epochframes+1:e*epochframes));
            if revfilt
                X(idxl+1:idxh-1)=0;
                if mod(length(X),2) == 0
                    X(end/2:end)=0;
                else
                    X((end+1)/2:end)=0;
                end;
            else
                X(1:idxl)=0;
                X(end-idxl:end)=0;
                X(idxh:end)=0;
            end;                
            smoothdata(c,(e-1)*epochframes+1:e*epochframes) = 2*real(ifft(X));
        end
    end
end


