function [numberOfSamplesRead sample] = mr_read_simulated(doReset)
% read data from mr.simulation.data variable instead of DataRiver.
% This is useful for simulating a realtime situation. Data is provided
% based on a realistic scenario in which only a limited number of frames
% are available (produced) based on how long the simulated session has been
% runinng. 

if nargin<1
    doReset = false;
end;

global mr;

persistent counter;
persistent timeAtTheFirstRun;

simulatedSamplingrate = round(mr.samplingRate * mr.simulation.speedFactor); % re-play data with  times the sped of realtime

%initialized as an empty set so we set it to 1.
if isempty(counter) || doReset
    counter = 1;
    timeAtTheFirstRun = tic;
    mr.eeg.channelOffset = 0;
end;


% if a sample that could not be available since the ammount of simulated
% data could be produced in the experiment, return no samples
if counter > toc(timeAtTheFirstRun) * simulatedSamplingrate
    numberOfSamplesRead = 0;
    sample.Data = [];
    sample.nItems = 0;
    return;
end;


sample.nItems = size(mr.simulation.data, 1);

if counter<size(mr.simulation.data, 2)
    sample.Data = mr.simulation.data(:, counter);
    numberOfSamplesRead = 1;
else % send zeros after all the data is sent.
    mr.simulation.data = zeros(sample.nItems, 1);
    numberOfSamplesRead  = 0;
    
    % warp around
    counter = 1;
end

counter = counter + 1;