
%arrowOrientation = arrowOrientation / norm(arrowOrientation, 'fro');

% set up the figure

figure('renderer', 'opengl');
view(30,30);
axis equal;
set(gca, 'xlimMode', 'manual'); 
set(gca, 'ylimMode', 'manual');
set(gca, 'zlimMode', 'manual');
hold on;

% size of 3d axis space
maxOnEachSide = 50;
set(gca, 'xlim', [-maxOnEachSide maxOnEachSide]);
set(gca, 'ylim',[-maxOnEachSide maxOnEachSide] );
set(gca, 'zlim', [-maxOnEachSide maxOnEachSide]);


set(gca, 'xticklabel',[])
set(gca, 'yticklabel',[])
xlabel('X');
ylabel('Y');

forceArrowHandle=[];
momentArrowHandle = [];
forcePlateHandle  =[];


arrowStart = [0 0 0];
cylinderHandle =[];

% force platform and its homogeneous transform
forcePlateHandle = cube([-20 -20 -3] ,[40 40 6], 1);
set(forcePlateHandle, 'facecolor',[0 0.4 0.4]);

placeHgTransform = hgtransform('Parent', gca);
set(forcePlateHandle,'Parent',placeHgTransform)

% place transprent ground 
groundhandle = patch([-maxOnEachSide -maxOnEachSide maxOnEachSide maxOnEachSide -maxOnEachSide], [-maxOnEachSide maxOnEachSide maxOnEachSide -maxOnEachSide -maxOnEachSide], [0 0 0 0 0], 'facealpha' ,0.2);

set(groundhandle, 'FaceVertexAlphaData',0.2);
set(groundhandle, 'FaceAlpha','flat');
set(groundhandle, 'FaceColor',[0.6 0.2 0]);



% use actual force and moment data

force = EEG.data(1:3,2000:end);
moment = EEG.data(4:6,2000:end);

momentScale = 1/ 2000;
forceScale = 1/ 30;
momentVectorScale = 1 /30;

for i=1:20:size(force, 2)
    
    %delete(forceArrowHandle);
    %delete(momentArrowHandle);
    
    lastForceArrowHandle = forceArrowHandle;
    lastMomentArrowHandle = momentArrowHandle;
    
    % force arrow
    forceArrowEnd = force(:, i)' * forceScale;
    forceArrowOrientation = forceArrowEnd - arrowStart;
    forceArrowHandle = quiver3(arrowStart(1),arrowStart(2),arrowStart(3), forceArrowOrientation(1),forceArrowOrientation(2),forceArrowOrientation(3),'filled', 'linewidth',2 ,'color',[1 0 0]);
    
    % moment arrow
    
    rotationMatrix = makehgtform('xrotate', moment(1, i) * momentScale, 'yrotate', moment(2, i) * momentScale,'zrotate', moment(3, i) * momentScale);
        
    % moment size is shown by rotating a vector (originally in +z) and size
    % modulatd by moment size
    momentArrowEnd = rotationMatrix * [0 0 norm(moment(:, i) * momentVectorScale, 'fro') 1]';
    
    momentArrowOrientation = momentArrowEnd(1:3)' - arrowStart;
    momentArrowHandle = quiver3(arrowStart(1),arrowStart(2),arrowStart(3), momentArrowOrientation(1),momentArrowOrientation(2),momentArrowOrientation(3),'filled', 'linewidth',2 ,'color',[0 0 1]);
    
    
    % force platform tilt
    set(placeHgTransform,'Matrix',rotationMatrix);
    
    
    delete(lastForceArrowHandle);
    delete(lastMomentArrowHandle);
    
    pause(0.1)
    
    
end;

%% ground
%figure
groundhandle = patch([-maxOnEachSide -maxOnEachSide maxOnEachSide maxOnEachSide -maxOnEachSide], [-maxOnEachSide maxOnEachSide maxOnEachSide -maxOnEachSide -maxOnEachSide], [0 0 0 0 0], 'facealpha' ,0.2);

set(groundhandle, 'FaceVertexAlphaData',0.2);
set(groundhandle, 'FaceAlpha','flat');
%% using random values

moment = [0.2 0 0.2];
force = [10 10 50];


for i=1:1000
    delete(forceArrowHandle);
    delete(momentArrowHandle);
    
    % force arrow
    force = force + 0*[0.5-rand 0.5-rand 0.5-rand]*5;
    forceArrowEnd = force * 1.1;
    forceArrowOrientation = forceArrowEnd - arrowStart;
    forceArrowHandle = quiver3(arrowStart(1),arrowStart(2),arrowStart(3), forceArrowOrientation(1),forceArrowOrientation(2),forceArrowOrientation(3),'filled', 'linewidth',3 ,'color',[1 0 0]);
    
    % moment arrow
    
    rotationMatrix = makehgtform('xrotate', moment(1), 'yrotate', moment(2),'zrotate', moment(3));
    
    moment = moment + [0.5-rand 0.5-rand 0.5-rand]*0.1;
    % moment size is shown by rotating a vector (originally in +z) and size
    % modulatd by moment size
    momentArrowEnd = rotationMatrix * 50*[0 0 1+norm(moment, 'fro') 1]';
    
    momentArrowOrientation = momentArrowEnd(1:3)' - arrowStart;
    momentArrowHandle = quiver3(arrowStart(1),arrowStart(2),arrowStart(3), momentArrowOrientation(1),momentArrowOrientation(2),momentArrowOrientation(3),'filled', 'linewidth',3 ,'color',[0 0 1]);
    
    
    % force platform tilt
    set(placeHgTransform,'Matrix',rotationMatrix);
    
    
    drawnow;
end;
