% In this tutorial we read and visualize data in a simulated realtime
% manner.
%
% You will see a figure showing data flowing into MatRiver system. To stop
% this tutorial, type 'delete(timerfindall);'(deletes all timers) before
% closing the figure showing data flow.
%
% type mr to see how mr structure fields are populated with values:
%   mr.readFromDataRiver is set to 0 to indicate simulated realtime mode.
%   mr.samplingRate shows that the data is sampled at 256 Hz
%   mr.numberOfChannelsInAccumulatedData shows that there are 290 incoming
%   data channels.
%   mr.eventChannelNumber shows that events are located at channel 290
%
%

% load mr structure prepared for this tutorial
load tutorial_mr_structure.mat;

% show the content of mr variable
mr

% reset the state of the function that send simulated data, this is
% necessary before starting the timer.
mr_read_simulated(true); 

% initiate 
mr_record_lag(true);

% delete all timers;
delete(timerfindall);

% define and then start the main MatRiver timer
if isempty(timerfind('tag','accumulatorTimer'))
    
    % this timer executes certain commands (specified after 'TimerFcn' key)
    % each 0.1 seconds. It does not block the command line so you can still
    % examine the variables and work with matlab while MatRiver is running.
    accumulatorTimer = timer('TimerFcn','mr_accumulate;mr_viewdata;mr_record_lag','StartDelay',0,'ExecutionMode','fixedSpacing','Period',0.1,'tag','accumulatorTimer');   
    
    % start the timer
    start(accumulatorTimer);
end;